\name{TileReadCel}
\alias{TileReadCel}
\title{TileReadCel}
\usage{TileReadCel(cel.filename, cel2.filename, celinc.filename,
    bpmap.filename, minhits=8000, group="Hs", pmonly=TRUE,
    mmonly=FALSE, normalize=TRUE, gc=TRUE, matchscore=FALSE,
    verbose=FALSE)}
\description{Reads tiling array data from an Affymetrix BPMAP file and CEL file(s).}
\details{Reads tiling array data in terms of an Affymetrix BPMAP (binary probe
mapping) file and the Affymetrix CEL file that are created by the Affymetrix
pipeline. The CEL file stores the results of the intensity calculations on
the pixel values of the DAT file. This includes among others an intensity
value, standard deviation of the intensity, and the coordinates of each
PM/MM probe on the tiling array. These coordinate information can be merged
with the Affymetrix BPMAP file that also comprises further information on the
probes. This includes the genomic location of each probe in terms of the
reference sequence and the probe center position, probe sequence for the GC
calculation, and the corresponding probe sequence length. The method
generates a \code{data.frame} comprising all required data on probes that
are necessary for the subsequent shuffling analysis.}
\value{Returns a \code{data.frame} containing information on all probes,
i.e., the full name of the reference sequence (organism abbreviation
and chromosome name), the chromosome name, the probe center position,
the length of the probe sequence, the GC content of the probe
sequence, the match score (if \code{matchscore} is enabled), and
the \code{log2} probe intensity or the probe \code{log2}-fold change.}
\arguments{\item{cel.filename}{A \code{vector} of one or more filenames of Affymetrix
CEL files (as \code{character}) that contain the probe intensities in
the first cellular condition. Note that replicates are simply defined
by more than one filename. In case \code{cel2.filename} is set to
\code{NULL}, the median probe \code{log2}-intensity among the given
replicates (\code{cel.filename}) is reported as estimate of the probe
intensity. On the other hand, if \code{cel2.filename} is given, the
median of all possible pairwise \code{log2}-fold changes between CEL
files from the first cellular condition (\code{cel.filename}) and
ones from the second cellular condition (\code{cel2.filename}) of a
probe will be reported as estimate of the probe intensity change.}
\item{cel2.filename}{A \code{vector} of one or more filenames of Affymetrix
CEL files (as \code{character}) that contain the probe intensities in
the second cellular condition. Note that replicates are simply
defined by more than one filename. This parameter is only required
in case of differential expression analysis where the median of all
possible pairwise \code{log2}-fold changes between CEL files from
the first cellular condition (\code{cel.filename}) and ones from the
second cellular condition (\code{cel2.filename}) of a probe will be
reported as estimate for the probe intensity change. Otherwise, the
parameter must be set to \code{NULL}.}
\item{celinc.filename}{A \code{vector} of one or more filenames of
Affymetrix CEL files (as \code{character}) containing probe
intensities that should be included in the normalization. This may
be desirable in case tiling array data of more than two different
cellular states is available and multiple transitions between them
are being analyzed. In the analysis of any of these transitions,
the CEL files corresponding to the remaining cellular states, i.e.,
those not given by \code{cel.filename} or \code{cel2.filename},
may be defined as \code{celinc.filename}. Hence, the full-quantile
normalization is always done on the entire set of avaiable intensity
data and the \code{log2}-fold changes among different analyzed
transitions are comparable and not biased by the normalization
procedure. This parameter is futile if \code{normalization} is
disabled.}
\item{bpmap.filename}{Filename of Affymetrix binary probe mapping (BPMAP)
file (as a \code{character}), which is a binary file containing
information on the location of each probe in the reference sequence.
Moreover, it stores the probe sequences that are necessary to
calculate the GC content.}
\item{minhits}{Minimal number of hits in BPMAP entry to be considered for
the further analysis. Due to historical reasons there are several
entries in the BPMAP file with only around thousand probes assigned
that might overlap with the larger entries or with entries on other
tiling arrays. In case of Affy tiling array 1.0R, a value of 8000
is recommended.}
\item{group}{A group name as the organism abbreviation in order to consider
only these entries in the BPMAP file and hence disregard entries such
as TIGR, Affymetrix, or bacterial controls.}
\item{pmonly}{Indicates whether only intensities of perfect match (PM)
probes on the Affymetrix tiling array are incorporated in the probe
intensity estimation. If neither \code{pmonly} nor \code{mmonly} is
set to \code{TRUE}, the specific hybridization effect of a probe is
estimated by taking \code{PM-MM}. Due to the issue of higher
intensities of mismatch (MM) probes compared to PM probes, it is
recommended to enable this parameter.}
\item{mmonly}{Indicates whether only intensities of mismatch (MM) probes
on the Affymetrix tiling array are incorporated in the probe
intensity estimation. If neither \code{pmonly} nor \code{mmonly} is
set to \code{TRUE}, the specific hybridaztion effect of a probe is
estimated by taking \code{PM-MM}. This option is mutually exclusive
with the \code{pmonly} parameter and is only recommended for
investigating the behaviour of mismatch probes on a tiling array
but not in common (differential) expression analyses.}
\item{normalize}{Indicates whether the probe intensities of the given CEL
files in \code{cel.filename}, \code{cel2.filename}, and
\code{celinc.filename} are normalized by use of full-quantile
normalization. The normalization is recommended if replicates are
available or a differential analysis is executed and, hence, the
transition between cellular states is analyzed. Note that both PM
and MM probes are included in the normalization regardless of the
\code{pmonly} or \code{mmonly} parameter.}
\item{gc}{Indicates whether GC content of probe sequences will be
calculated. It is defined as fraction of both Gs and Cs in the
probe sequence.}
\item{matchscore}{Indicates whether match score will be read. The match
score is defined as number of perfect matches of the probe sequence
per megabase of the genomic sequence. This information needs to be
set accordingly in the BPMAP file. Otherwise, all probes contain only
the default value.}
\item{verbose}{Indicates whether information on progress are printed.}}
\examples{## Note that the following example only executes if the external data
## of the Starr R package is available which includes an artificial
## Affymetrix BPMAP file and corresponding CEL files.
path <- system.file("extdata", package = "Starr")
if (path != ""){
## define Affymetrix BPMAP file for probe mapping
bpmap.filename <- file.path(path, "Scerevisiae_tlg_chr1.bpmap")
## define Affymetrix CEL files
## here: file of control experiment (wt)
wt.filename <- file.path(path, "wt_IP_chr1.cel")
stopifnot(file.exists(bpmap.filename) && file.exists(wt.filename))

## read CEL file and return data.frame
## with information such as genomic localization
## of probes, GC content of probe sequences,
## and probe intensities.
## Note that group is '' (blank) for old Affy chr21/22arrays
## while it is "Hs" for other Human, "Mm" for Mouse, or "Dm"
## for Drosophila tiling array platforms.
wt.cel <- TileReadCel(cel.filename=wt.filename,
bpmap.filename=bpmap.filename,
group="", gc=TRUE, verbose=FALSE)

## getting an overview on the reported data.frame
str(wt.cel)

## investigating data
## e.g. plot density of intensities
pdf(file="wt_int_density.pdf")
plot(density(wt.cel$intensity), main="", xlab="Intensity")
dev.off()
## or GC bias with three GC content bins
pdf(file="wt_gc_bias.pdf")
boxplot(wt.cel$intensity ~ cut(wt.cel$gc,
breaks=c(0,0.36,0.52,Inf),right=FALSE),
xlab="GC content", ylab="Intensity")
dev.off()
## cleanup
rm(bpmap.filename, wt.filename, wt.cel)
}
rm(path)}
